==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/DoubleValueChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DoubleValueChangedEventArgsDescription } from "./DoubleValueChangedEventArgsDescription";
/**
 * @hidden
 */
export let DoubleValueChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class DoubleValueChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (DoubleValueChangedEventArgsDescriptionMetadata.a == null) {
                DoubleValueChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                DoubleValueChangedEventArgsDescriptionMetadata.c(DoubleValueChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(DoubleValueChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(DoubleValueChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("OldValue", "Number:double");
            a.item("NewValue", "Number:double");
        }
        static d(a) {
            DoubleValueChangedEventArgsDescriptionMetadata.b(a);
            a.ad("DoubleValueChangedEventArgs", () => new DoubleValueChangedEventArgsDescription());
            a.ac("DoubleValueChangedEventArgs", DoubleValueChangedEventArgsDescriptionMetadata.a);
        }
    }
    DoubleValueChangedEventArgsDescriptionMetadata.$t = markType(DoubleValueChangedEventArgsDescriptionMetadata, 'DoubleValueChangedEventArgsDescriptionMetadata');
    DoubleValueChangedEventArgsDescriptionMetadata.a = null;
    return DoubleValueChangedEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/DoubleValueChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DoubleValueChangedEventArgsDescription } from "./DoubleValueChangedEventArgsDescription";
/**
 * @hidden
 */
export let DoubleValueChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class DoubleValueChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (DoubleValueChangedEventArgsDescriptionMetadata.a == null) {
                DoubleValueChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                DoubleValueChangedEventArgsDescriptionMetadata.c(DoubleValueChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(DoubleValueChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(DoubleValueChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("OldValue", "Number:double");
            a.item("NewValue", "Number:double");
        }
        static d(a) {
            DoubleValueChangedEventArgsDescriptionMetadata.b(a);
            a.ae("DoubleValueChangedEventArgs", () => new DoubleValueChangedEventArgsDescription());
            a.ad("DoubleValueChangedEventArgs", DoubleValueChangedEventArgsDescriptionMetadata.a);
        }
    }
    DoubleValueChangedEventArgsDescriptionMetadata.$t = markType(DoubleValueChangedEventArgsDescriptionMetadata, 'DoubleValueChangedEventArgsDescriptionMetadata');
    DoubleValueChangedEventArgsDescriptionMetadata.a = null;
    return DoubleValueChangedEventArgsDescriptionMetadata;
})();
